@@ -12,11 +12,14 @@ use log::{debug, info, trace, warn};
 use rand::prelude::*;
 use serde::Serialize;
 use serde_json::json;
+use std::collections::HashMap;
 use std::net::IpAddr;
 use std::time::SystemTime;
 use stop_token::{StopSource, StopToken};
 use uuid::Uuid;
 
+//@todo round 2, I think I need to break out of the concept of worker / miner being the same. We
+//need to create a miner structg that contains all of the data shit.
 #[derive(PartialEq, Debug)]
 pub enum ConnectionState {
     Connected,
@@ -56,6 +59,7 @@ pub struct Connection<State> {
     pub state: Arc<Mutex<State>>,
     pub stop_source: Arc<Mutex<Option<StopSource>>>,
     pub stop_token: StopToken,
+    pub worker_list: Arc<Mutex<HashMap<u16, WorkerInfo>>>,
 }
 
 //@todo review this. I'm not sure if this is the best strategy here, but I'd like for the ability
@@ -217,6 +221,7 @@ impl<State: Clone + Send + Sync + 'static> Connection<State> {
             state: Arc::new(Mutex::new(state)),
             stop_source: Arc::new(Mutex::new(Some(stop_source))),
             stop_token,
+            worker_list: Arc::new(Mutex::new(HashMap::new())),
         }
     }
 
@@ -518,6 +523,45 @@ impl<State: Clone + Send + Sync + 'static> Connection<State> {
         sid.to_hex()
     }
 
+    pub async fn register_worker(
+        &self,
+        session_id: u16,
+        client_agent: &str,
+        worker_name: &str,
+        worker_id: Uuid,
+    ) {
+        let worker = WorkerInfo {
+            client: Some(client_agent.to_owned()),
+            name: Some(worker_name.to_owned()),
+            //@todo I suppose this is technically session ID
+            sid: Some(Buffer::from(session_id.to_le_bytes().to_vec())),
+            //@todo we need to be careful of lockups here.
+            account_id: self.get_account_id().await,
+            miner_account: self.get_miner_account().await,
+            id: worker_id,
+        };
+
+        self.worker_list.lock().await.insert(session_id, worker);
+        //@todo one large thing we are missing here, and it's probs just for the above library but
+        //EVENTS so new event for new worker.
+    }
+
+    pub async fn unregister_worker(&self, session_id: u16) {
+        self.worker_list.lock().await.remove(&session_id);
+    }
+
+    pub async fn get_worker_by_session_id(&self, session_id: u16) -> Option<WorkerInfo> {
+        self.worker_list
+            .lock()
+            .await
+            .get(&session_id)
+            .map(|w| w.clone())
+    }
+
+    pub async fn update_worker_by_session_id(&self, session_id: u16, worker: WorkerInfo) {
+        self.worker_list.lock().await.insert(session_id, worker);
+    }
+
     // ===== Worker Helper functions ===== //
     pub async fn set_var_diff(&self, var_diff: bool) {
         *self.var_diff.lock().await = var_diff;
