@@ -1,5 +1,4 @@
-use crate::types::MessageValue;
-use extended_primitives::Buffer;
+use crate::types::{ExMessageGeneric, MessageValue};
 
 pub struct StratumRequest<State> {
     pub(crate) state: State,
@@ -13,29 +12,13 @@ impl<State> StratumRequest<State> {
         &self.state
     }
 
-    // //@todo maybe just kill these.
-    // pub fn get_stratum_v1_value(&self, name: &str) -> Option<&serde_json::Value> {
-    //     match &self.values {
-    //         MessageValue::StratumV1(value) => value.get(name),
-    //         MessageValue::ExMessage(_) => None,
-    //     }
-    // }
-
-    pub fn get_ex_message(&self) -> Option<Buffer> {
+    pub fn get_ex_message(&self) -> Option<ExMessageGeneric> {
         match &self.values {
             MessageValue::StratumV1(_) => None,
-            MessageValue::ExMessage(value) => Some(value.body.clone()),
+            MessageValue::ExMessage(value) => Some(value.clone()),
         }
     }
 
-    // //@todo this should actually return either I think.
-    // pub fn get(&self, name: &str) -> Option<&serde_json::Value> {
-    //     match self.values {
-    //         MessageValue::StratumV1(value) => value.get(name),
-    //         MessageValue::ExMessage(_) => None,
-    //     }
-    // }
-
     pub fn get_json<T: serde::de::DeserializeOwned>(
         &self,
         name: &str,
