@@ -1,7 +1,7 @@
 use crate::connection::Connection;
 use crate::router::Router;
 use crate::server::{UpstreamConfig, VarDiffConfig};
-use crate::types::MessageValue;
+use crate::types::{ExMessageGeneric, MessageValue};
 use crate::BanManager;
 pub use crate::MinerList;
 use crate::{Error, Result};
@@ -247,95 +247,13 @@ pub async fn handle_connection<
     }
 }
 
-pub enum MessageTypes {
-    RegisterWorker,
-    SubmitShare,
-    SubmitShareWithTime,
-    SubmitShareWithVersion,
-    SubmitShareWithTimeAndVersion,
-    UnregisterWorker,
-    MiningSetDiff,
-
-    Unknown(u8),
-}
-
-impl MessageTypes {
-    pub fn from_u8(cmd: u8) -> Self {
-        match cmd {
-            0x01 => MessageTypes::RegisterWorker,
-            0x02 => MessageTypes::SubmitShare,
-            0x03 => MessageTypes::SubmitShareWithTime,
-            0x04 => MessageTypes::UnregisterWorker,
-            0x05 => MessageTypes::MiningSetDiff,
-            //@note not sure why these are so far after the originals. Makes me think there are
-            //other messages we are missing here, but can figure that out later.
-            0x12 => MessageTypes::SubmitShareWithVersion,
-            0x13 => MessageTypes::SubmitShareWithTimeAndVersion,
-            _ => MessageTypes::Unknown(cmd),
-        }
-    }
-
-    pub fn to_string(&self) -> String {
-        match *self {
-            MessageTypes::RegisterWorker => String::from("exMessageRegisterWorker"),
-            MessageTypes::SubmitShare => String::from("exMessageSubmitShare"),
-            MessageTypes::SubmitShareWithTime => String::from("exMessageSubmitShareWithTime"),
-            MessageTypes::UnregisterWorker => String::from("exMessageUnregisterWorker"),
-            MessageTypes::MiningSetDiff => String::from("exMessageMiningSetDiff"),
-            MessageTypes::SubmitShareWithVersion => String::from("exMessageSubmitShareWithVersion"),
-            MessageTypes::SubmitShareWithTimeAndVersion => {
-                String::from("exMessageSubmitShareWithTimeAndVersion")
-            }
-            //@todo I'd actually prefer we throw an error here but we can come back to that later
-            //as well.
-            //But seems important for security otherwise someone could just hit us with fake Ex
-            //messages all day.
-            _ => String::from(""),
-        }
-    }
-}
-
 // ex-message:
 //   magic_number	uint8_t		magic number for Ex-Message, always 0x7F
 //   type/cmd		uint8_t		message type
 //   length			uint16_t	message length (include header self)
 //   message_body	uint8_t[]	message body
 //btc agent style messages.
-pub struct ExMessageGeneric {
-    pub magic_number: u8,
-    //@todo turn this into an Enum?
-    pub cmd: MessageTypes,
-    pub length: u16,
-    pub body: Buffer,
-}
 
-//@todo let's make sure we get some good errors in here for if this shit blows up.
-impl ExMessageGeneric {
-    //@todo actually just call this inside of that function.
-    pub fn from_buffer(buffer: &mut Buffer) -> Result<Self> {
-        let magic_number = buffer.read_u8().map_err(|_| Error::BrokenExHeader)?;
-        let cmd = buffer.read_u8().map_err(|_| Error::BrokenExHeader)?;
-        let length = buffer.read_u16().map_err(|_| Error::BrokenExHeader)?;
-
-        let body = buffer.clone();
-
-        let cmd = MessageTypes::from_u8(cmd);
-
-        // if cmd == MessageTypes::Unknown(_) {
-        //@todo custom error here pls.
-        // return Error::
-        // }
-
-        Ok(ExMessageGeneric {
-            magic_number,
-            cmd,
-            length,
-            body,
-        })
-    }
-}
-
-//@todo I think we are going to have to change the return method of this...
 pub async fn next_message(
     stream: &mut BufReader<ReadHalf<TcpStream>>,
 ) -> Result<(String, MessageValue)> {
@@ -364,7 +282,7 @@ pub async fn next_message(
             let ex_message = ExMessageGeneric::from_buffer(&mut buffer)?;
             return Ok((
                 ex_message.cmd.to_string(),
-                MessageValue::ExMessage(ex_message.body.clone()),
+                MessageValue::ExMessage(ex_message),
             ));
         }
 
